# -*- coding: utf-8 -*-

from ..timetable import TimetableFactory, Category
from datetime import timedelta, datetime

"""
Backend for the user's personal recurring events.
"""


def get_timetables_for(user, result):
    """
    Backend main function
    Returns the custom timetables for the specified user in the result list.
    """

    # Get all days between start and end
    start, end = TimetableFactory.get_limits()
    days_number = (end - start).days + 1
    days = [start + timedelta(days=i) for i in range(days_number)]

    events = user.edtrecurring.all()

    factory = TimetableFactory(f"Événements personnels récurrents de {user}")

    for day in days:
        for event in events:
            if day.weekday() == event.weekday:
                midnight = datetime.combine(day, datetime.min.time())
                description = None
                if event.category == Category.COURS:
                    description = "Cours"
                factory.add_event(
                    midnight + timedelta(hours=event.start_hour),
                    midnight + timedelta(hours=event.end_hour),
                    event.topic,
                    description,
                    event.category,
                    [event.location],
                    [event.people],
                    f"recurring-{event.id}",
                )

    result.append(factory.table)
